@@ -67,3 +67,9 @@ Config.define('SCHEMA_ORG_ITEMTYPE', [], 'List of Schema.Org ItemType', 'Schema.
 Config.define('FORCE_CANONICAL', False, 'Force canonical', 'Force canonical')
 
 Config.define('BLACKLIST_DOMAIN', [], 'Domain blacklist', 'Domain blacklist')
+
+Config.define('ERROR_HANDLERS', [], 'List of classes to handle errors', 'General')
+
+# SENTRY ERROR HANDLER
+Config.define('USE_SENTRY', False, 'If set to true errors will be sent to sentry.', 'Sentry')
+Config.define('SENTRY_DSN_URL', '', 'URL to use as sentry DSN.', 'Sentry')
